#!/bin/sh
#
# Check or create osgi-runner hostkey
#

# include prerequisites
. /usr/share/osgi-runner/sh/check-dirs.sh

if test -f $OSGI_ETCDIR/sshd.d/host.key ; then
    echo "WARNING: Found existing $OSGI_ETCDIR/sshd.d/host.key this key will not be used anymore, correct your known_hosts files."
fi

GOGO_SSH_ALGO=$(sed -e 's/^ *gogo\.ssh\.hostKeyAlgorithm *= *\(RSA\|EC\|EdDSA\)/\1/p;d' $OSGI_ETCDIR/conf.d/gogo-ssh.properties)

SSH_BITS=$(sed -e 's/^ *gogo\.ssh\.hostKeySize *= *\([0-9][0-9]*\)/\1/p;d' /etc/osgi-runner/conf.d/gogo-ssh.properties)

case "$GOGO_SSH_ALGO" in
   "RSA")
       SSH_ALGO=rsa
       test "$SSH_BITS" = "" && SSH_BITS=3072
      ;;
   "EC")
       SSH_ALGO=ecdsa
       test "$SSH_BITS" = "" && SSH_BITS=256
      ;;
   "EdDSA")
       SSH_ALGO=ed25519
       test "$SSH_BITS" = "" && SSH_BITS=256
      ;;
   *)
       echo "WARNING: gogo.ssh.hostKeyAlgorithm not found in $OSGI_ETCDIR/conf.d/gogo-ssh.properties, assuming ed25519 keys."
       SSH_ALGO=ed25519
       test "$SSH_BITS" = "" && SSH_BITS=256
     ;;
esac


if test -f $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key ; then
    echo "Found existing $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key, not creating it now."
else

    echo "No $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key, preparing to create it ..."
    
    SSHKEYGEN="/usr/bin/ssh-keygen"
    if test ! -x "$SSHKEYGEN"
    then
        echo "Cannot find ${SSHKEYGEN}"
        exit 3
    fi

    echo "Creating $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key with ${SSH_BITS} bits..."
    $SSHKEYGEN -t $SSH_ALGO -N '' -b $SSH_BITS -f $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key || exit 11
    chgrp $OSGI_GROUP $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key
    chmod 640 $OSGI_ETCDIR/sshd.d/ssh_host_${SSH_ALGO}_key

fi

if test -f $OSGI_ETCDIR/htpasswd.d/osgi.htpasswd ; then
    echo "Found existing $OSGI_ETCDIR/htpasswd.d/osgi.htpasswd, not creating it now."
else

    echo "No $OSGI_ETCDIR/htpasswd.d/osgi.htpasswd, creating it now ..."

     "$JAVA_EXE" -jar $OSGI_BASE/aux/htpasswd-jaas-*.jar adduser $OSGI_ETCDIR/htpasswd.d/osgi.htpasswd osgi
    chgrp $OSGI_GROUP $OSGI_ETCDIR/htpasswd.d/osgi.htpasswd
    chmod 640 $OSGI_ETCDIR/htpasswd.d/osgi.htpasswd
fi

exit 0
